@@ -9,7 +9,7 @@ def get_bookmark(state, repo, stream_name, bookmark_key, start_date):
     """
     Return bookmark value if available in the state otherwise return start date
     """
-    repo_stream_dict = bookmarks.get_bookmark(state, repo, stream_name)
+    repo_stream_dict = bookmarks.get_bookmark(state, stream_name, repo)
     if repo_stream_dict:
         return repo_stream_dict.get(bookmark_key)
 
@@ -119,7 +119,7 @@ class Stream:
 
         # If the stream is selected, write the bookmark.
         if stream in selected_streams:
-            singer.write_bookmark(state, repo_path, stream_obj.tap_stream_id, {"since": bookmark_value})
+            singer.write_bookmark(state, stream_obj.tap_stream_id, repo_path, {"since": bookmark_value})
 
         # For the each child, write the bookmark if it is selected.
         for child in stream_obj.children:
@@ -205,14 +205,14 @@ class Stream:
 
 class FullTableStream(Stream):
     def sync_endpoint(self,
-                        client,
-                        state,
-                        catalog,
-                        repo_path,
-                        start_date,
-                        selected_stream_ids,
-                        stream_to_sync
-                        ):
+                      client,
+                      state,
+                      catalog,
+                      repo_path,
+                      start_date,
+                      selected_stream_ids,
+                      stream_to_sync
+                      ):
         """
         A common function sync full table streams.
         """
@@ -517,46 +517,6 @@ class PullRequests(IncrementalOrderedStream):
     children = ['reviews', 'review_comments', 'pr_commits']
     pk_child_fields = ["number"]
 
-class ProjectCards(IncrementalStream):
-    '''
-    https://docs.github.com/en/rest/reference/projects#list-project-cards
-    '''
-    tap_stream_id = "project_cards"
-    replication_method = "INCREMENTAL"
-    replication_keys = "updated_at"
-    key_properties = ["id"]
-    path = "projects/columns/{}/cards"
-    tap_stream_id = "project_cards"
-    parent = 'project_columns'
-    id_keys = ['id']
-
-class ProjectColumns(IncrementalStream):
-    '''
-    https://docs.github.com/en/rest/reference/projects#list-project-columns
-    '''
-    tap_stream_id = "project_columns"
-    replication_method = "INCREMENTAL"
-    replication_keys = "updated_at"
-    key_properties = ["id"]
-    path = "projects/{}/columns"
-    children = ["project_cards"]
-    parent = "projects"
-    id_keys = ['id']
-    has_children = True
-
-class Projects(IncrementalStream):
-    '''
-    https://docs.github.com/en/rest/reference/projects#list-repository-projects
-    '''
-    tap_stream_id = "projects"
-    replication_method = "INCREMENTAL"
-    replication_keys = "updated_at"
-    key_properties = ["id"]
-    path = "projects?state=all"
-    tap_stream_id = "projects"
-    children = ["project_columns"]
-    child_objects = [ProjectColumns()]
-
 class TeamMemberships(FullTableStream):
     '''
     https://docs.github.com/en/rest/reference/teams#get-team-membership-for-a-user
@@ -753,9 +713,6 @@ STREAMS = {
     "events": Events,
     "commit_comments": CommitComments,
     "issue_milestones": IssueMilestones,
-    "projects": Projects,
-    "project_columns": ProjectColumns,
-    "project_cards": ProjectCards,
     "pull_requests": PullRequests,
     "reviews": Reviews,
     "review_comments": ReviewComments,
